@@ -1,9 +1,9 @@
 //use regex::Regex;
-use onig::*;
-use structs::NumberingFormat;
-use structs::Color;
-use thousands::{Separable};
 use helper::date::*;
+use onig::*;
+use structs::Color;
+use structs::NumberingFormat;
+use thousands::Separable;
 
 const DATE_FORMAT_REPLACEMENTS: &'static [(&'static str, &'static str)] = &[
     // first remove escapes related to non-format characters
@@ -50,17 +50,13 @@ const DATE_FORMAT_REPLACEMENTS: &'static [(&'static str, &'static str)] = &[
     (".s", ""),
 ];
 
-const DATE_FORMAT_REPLACEMENTS_24: &'static [(&'static str, &'static str)] = &[
-    ("hh", "%H"),
-    ("h", "%-H"),
-];
+const DATE_FORMAT_REPLACEMENTS_24: &'static [(&'static str, &'static str)] =
+    &[("hh", "%H"), ("h", "%-H")];
 
-const DATE_FORMAT_REPLACEMENTS_12: &'static [(&'static str, &'static str)] = &[
-    ("hh", "%I"),
-    ("h", "%-I"),
-];
+const DATE_FORMAT_REPLACEMENTS_12: &'static [(&'static str, &'static str)] =
+    &[("hh", "%I"), ("h", "%-I")];
 
-pub fn to_formatted_string<S: Into<String>>(value:S, format:S)-> String {
+pub fn to_formatted_string<S: Into<String>>(value: S, format: S) -> String {
     let mut value = value.into();
     let mut format = format.into();
 
@@ -71,8 +67,8 @@ pub fn to_formatted_string<S: Into<String>>(value:S, format:S)-> String {
 
     // is numeric
     match &value.parse::<f64>() {
-        Ok(_) => {},
-        Err(_) => return value
+        Ok(_) => {}
+        Err(_) => return value,
     }
 
     // convert value
@@ -84,12 +80,13 @@ pub fn to_formatted_string<S: Into<String>>(value:S, format:S)-> String {
     }
 
     // Convert any other escaped characters to quoted strings, e.g. (\T to "T")
-    let re = Regex::new(r#"(\\\(((.)(?!((AM\/PM)|(A\/P)))|([^ ])))(?=(?:[^"]|"[^"]*")*$)"#).unwrap();
+    let re =
+        Regex::new(r#"(\\\(((.)(?!((AM\/PM)|(A\/P)))|([^ ])))(?=(?:[^"]|"[^"]*")*$)"#).unwrap();
     format = re.replace_all(&format, r#""$0""#);
-    
+
     // Get the sections, there can be up to four sections, separated with a semi-colon (but only if not a quoted literal)
     let re = Regex::new(r#"(;)(?=(?:[^"]|"[^"]*")*$)"#).unwrap();
-    let sections:Vec<&str> = re.split(&format).collect();
+    let sections: Vec<&str> = re.split(&format).collect();
 
     let (_, split_format, split_value) = split_format(sections, &value.parse::<f64>().unwrap());
     format = split_format;
@@ -122,21 +119,26 @@ pub fn to_formatted_string<S: Into<String>>(value:S, format:S)-> String {
     value.trim().to_string()
 }
 
-fn format_as_percentage(value:&f64, format:&str)-> String {
+fn format_as_percentage(value: &f64, format: &str) -> String {
     let mut value = value.to_string();
     let mut format = format.to_string();
     format = format.replace("%", "");
-    let blocks:Vec<&str> = format.split('.').collect();
+    let blocks: Vec<&str> = format.split('.').collect();
     let len = match blocks.get(1) {
         Some(v) => v.len(),
-        None => 0
+        None => 0,
     };
-    value = format!("{:0width$.len$}%", (100f64 * &value.parse::<f64>().unwrap()).round(), width = 1, len = len);
+    value = format!(
+        "{:0width$.len$}%",
+        (100f64 * &value.parse::<f64>().unwrap()).round(),
+        width = 1,
+        len = len
+    );
     value
 }
 
-fn split_format(sections:Vec<&str>, value:&f64)-> (String, String, String) {
-    let mut converted_sections:Vec<String> = Vec::new();
+fn split_format(sections: Vec<&str>, value: &f64) -> (String, String, String) {
+    let mut converted_sections: Vec<String> = Vec::new();
 
     // Extract the relevant section depending on whether number is positive, negative, or zero?
     // Text not supported yet.
@@ -145,41 +147,59 @@ fn split_format(sections:Vec<&str>, value:&f64)-> (String, String, String) {
     //   2 sections:  [POSITIVE/ZERO/TEXT] [NEGATIVE]
     //   3 sections:  [POSITIVE/TEXT] [NEGATIVE] [ZERO]
     //   4 sections:  [POSITIVE] [NEGATIVE] [ZERO] [TEXT]
-    let cnt:usize = sections.len();
-    let color_regex:String = format!("{}{}{}", "\\[(", Color::NAMED_COLORS.join("|"), ")\\]");
+    let cnt: usize = sections.len();
+    let color_regex: String = format!("{}{}{}", "\\[(", Color::NAMED_COLORS.join("|"), ")\\]");
     let cond_regex = r#"\[(>|>=|<|<=|=|<>)([+-]?\d+([.]\d+)?)\]"#;
     let color_re = Regex::new(&color_regex).unwrap();
     let cond_re = Regex::new(&cond_regex).unwrap();
-    
-    let mut colors = [String::from(""), String::from(""), String::from(""), String::from(""), String::from("")];
-    let mut condops = [String::from(""), String::from(""), String::from(""), String::from(""), String::from("")];
-    let mut condvals = [String::from("0"), String::from("0"), String::from("0"), String::from("0"), String::from("0")];
+
+    let mut colors = [
+        String::from(""),
+        String::from(""),
+        String::from(""),
+        String::from(""),
+        String::from(""),
+    ];
+    let mut condops = [
+        String::from(""),
+        String::from(""),
+        String::from(""),
+        String::from(""),
+        String::from(""),
+    ];
+    let mut condvals = [
+        String::from("0"),
+        String::from("0"),
+        String::from("0"),
+        String::from("0"),
+        String::from("0"),
+    ];
     let mut idx = 0;
     for section in sections {
         let mut converted_section = section.to_string();
         if color_re.find(section).is_some() {
-            let mut item:Vec<String> = Vec::new();
+            let mut item: Vec<String> = Vec::new();
             for ite in color_re.captures(section).unwrap().iter() {
                 item.push(ite.unwrap().to_string());
             }
-            std::mem::replace(&mut colors[idx], item.get(0).unwrap().to_string());
+            let _ = std::mem::replace(&mut colors[idx], item.get(0).unwrap().to_string());
             converted_section = color_re.replace_all(section, "").to_string();
         }
         if cond_regex.find(section).is_some() {
-            let mut item:Vec<String> = Vec::new();
+            let mut item: Vec<String> = Vec::new();
             for ite in cond_re.captures(section).unwrap().iter() {
                 item.push(ite.unwrap().to_string());
             }
-            std::mem::replace(&mut condops[idx], item.get(1).unwrap().to_string());
-            std::mem::replace(&mut condvals[idx], item.get(2).unwrap().to_string());
+            let _ = std::mem::replace(&mut condops[idx], item.get(1).unwrap().to_string());
+            let _ = std::mem::replace(&mut condvals[idx], item.get(2).unwrap().to_string());
             converted_section = cond_re.replace_all(section, "").to_string();
         }
         converted_sections.insert(idx, converted_section);
-        idx+=1;
+        idx += 1;
     }
 
     let mut color = colors[0].clone();
-    let mut format:&str = &converted_sections[0];
+    let mut format: &str = &converted_sections[0];
     let mut absval = value.clone();
     match cnt {
         2 => {
@@ -189,7 +209,7 @@ fn split_format(sections:Vec<&str>, value:&f64)-> (String, String, String) {
                 color = colors[1].clone();
                 format = &converted_sections[1];
             }
-        },
+        }
         3 | 4 => {
             absval = absval.abs();
             let condval_one = &condvals[0].parse::<f64>().unwrap();
@@ -203,14 +223,13 @@ fn split_format(sections:Vec<&str>, value:&f64)-> (String, String, String) {
                     format = &converted_sections[2];
                 }
             }
-
-        },
-        _ => {},
+        }
+        _ => {}
     }
     (color.into(), format.into(), absval.to_string())
 }
 
-fn split_format_compare(value:&f64, cond:&str, val:&f64, dfcond:&str, dfval:&f64)->bool {
+fn split_format_compare(value: &f64, cond: &str, val: &f64, dfcond: &str, dfval: &f64) -> bool {
     let mut check_cond = cond;
     let mut check_val = val;
     if cond == "" {
@@ -228,7 +247,7 @@ fn split_format_compare(value:&f64, cond:&str, val:&f64, dfcond:&str, dfval:&f64
     value >= check_val
 }
 
-fn format_as_date(value:&f64, format:&str)-> String {
+fn format_as_date(value: &f64, format: &str) -> String {
     let value = value;
     let mut format = format.to_string();
 
@@ -242,16 +261,14 @@ fn format_as_date(value:&f64, format:&str)-> String {
     // OpenOffice.org uses upper-case number formats, e.g. 'YYYY', convert to lower-case;
     //    but we don't want to change any quoted strings
     let re = Regex::new(r#"(?:^|")([^"]*)(?:$|")"#).unwrap();
-    format = re.replace_all(&format,
-        |caps: &Captures| {
-            let caps_string: String = (&caps.at(0).unwrap()).parse().unwrap();
-            caps_string.to_lowercase()
-        }
-    );
+    format = re.replace_all(&format, |caps: &Captures| {
+        let caps_string: String = (&caps.at(0).unwrap()).parse().unwrap();
+        caps_string.to_lowercase()
+    });
 
     // Only process the non-quoted blocks for date format characters
-    let blocks:Vec<&str> = format.split('"').collect();
-    let mut converted_blocks:Vec<String> = Vec::new();
+    let blocks: Vec<&str> = format.split('"').collect();
+    let mut converted_blocks: Vec<String> = Vec::new();
     let mut i = 0;
     for block in blocks {
         let mut block = block.to_string();
@@ -284,18 +301,16 @@ fn format_as_date(value:&f64, format:&str)-> String {
 
     // escape any quoted characters so that DateTime format() will render them correctly
     let re = Regex::new(r#""(.*)""#).unwrap();
-    format = re.replace_all(&format,
-        |caps: &Captures| {
-            let caps_string: String = (&caps.at(0).unwrap()).parse().unwrap();
-            caps_string.to_lowercase()
-        }
-    );
+    format = re.replace_all(&format, |caps: &Captures| {
+        let caps_string: String = (&caps.at(0).unwrap()).parse().unwrap();
+        caps_string.to_lowercase()
+    });
 
     let date_obj = excel_to_date_time_object(value, None);
     date_obj.format(&format).to_string()
 }
 
-fn format_as_number(value:&f64, format:&str)-> String {
+fn format_as_number(value: &f64, format: &str) -> String {
     let mut value = value.to_string();
 
     // The "_" in this string has already been stripped out,
@@ -322,10 +337,10 @@ fn format_as_number(value:&f64, format:&str)-> String {
     // Scale thousands, millions,...
     // This is indicated by a number of commas after a digit placeholder:
     //        #,   or    0.0,,
-    let mut scale:f64 = 1f64; // same as no scale
+    let mut scale: f64 = 1f64; // same as no scale
     let re = Regex::new(r#"(#|0)(,+)"#).unwrap();
     if re.find(&format).is_some() {
-        let mut matches:Vec<String> = Vec::new();
+        let mut matches: Vec<String> = Vec::new();
         for ite in re.captures(&format).unwrap().iter() {
             matches.push(ite.unwrap().to_string());
         }
@@ -338,10 +353,10 @@ fn format_as_number(value:&f64, format:&str)-> String {
 
     if Regex::new(r#"#?.*\?\/\?"#).unwrap().find(&format).is_some() {
         match &value.parse::<usize>() {
-            Ok(_) => {},
+            Ok(_) => {}
             Err(_) => {
                 value = format_as_fraction(&value.parse::<f64>().unwrap(), &format);
-            },
+            }
         }
     } else {
         // Handle the number itself
@@ -353,44 +368,57 @@ fn format_as_number(value:&f64, format:&str)-> String {
         // Remove \
         format = Regex::new(r#"\\"#).unwrap().replace_all(&format, "");
         // Remove locale code [$-###]
-        format = Regex::new(r#"\[\$\-.*\]"#).unwrap().replace_all(&format, "");
+        format = Regex::new(r#"\[\$\-.*\]"#)
+            .unwrap()
+            .replace_all(&format, "");
         // Trim
         format = format.trim().to_string();
 
-        let m = Regex::new(r#"\[[^\]]+\]"#).unwrap().replace_all(&format, "");
+        let m = Regex::new(r#"\[[^\]]+\]"#)
+            .unwrap()
+            .replace_all(&format, "");
         let number_regex = r#"(0+)(\.?)(0*)"#;
         let re = Regex::new(number_regex).unwrap();
         if re.find(&m).is_some() {
-            let mut item:Vec<String> = Vec::new();
+            let mut item: Vec<String> = Vec::new();
             for ite in re.captures(&m).unwrap().iter() {
                 item.push(ite.unwrap().to_string());
             }
-            value = format_straight_numeric_value(&value, &format, &item, &use_thousands, number_regex);
+            value =
+                format_straight_numeric_value(&value, &format, &item, &use_thousands, number_regex);
         }
     }
 
     let re = Regex::new(r#"\$[^0-9]*"#).unwrap();
     if re.find(&format).is_some() {
-        let mut item:Vec<String> = Vec::new();
+        let mut item: Vec<String> = Vec::new();
         for ite in re.captures(&format).unwrap().iter() {
             item.push(ite.unwrap().to_string());
         }
         value = format!("{}{}", item.get(0).unwrap(), value);
-    //    //  Currency or Accounting
-    //    let currency_code = item.get(1).unwrap().to_string();
-    //    value = Regex::new(r#"\[\$([^\]]*)\]"#).unwrap().replace_all(&value, currency_code.as_str()).to_string();
+        //    //  Currency or Accounting
+        //    let currency_code = item.get(1).unwrap().to_string();
+        //    value = Regex::new(r#"\[\$([^\]]*)\]"#).unwrap().replace_all(&value, currency_code.as_str()).to_string();
     }
 
     value
 }
 
-fn format_as_fraction(value:&f64, format:&str)-> String {
+fn format_as_fraction(value: &f64, format: &str) -> String {
     let sign = if value < &0f64 { "-" } else { "" };
 
     let integer_part = value.abs().floor();
-    let decimal_part = (value.abs() % 1f64).to_string().replace("0.", "").parse::<f64>().unwrap();
+    let decimal_part = (value.abs() % 1f64)
+        .to_string()
+        .replace("0.", "")
+        .parse::<f64>()
+        .unwrap();
     let decimal_length = decimal_part.to_string().len();
-    let decimal_divisor = 10i32.pow(decimal_length as u32).to_string().parse::<f64>().unwrap();
+    let decimal_divisor = 10i32
+        .pow(decimal_length as u32)
+        .to_string()
+        .parse::<f64>()
+        .unwrap();
 
     let gcd = gcd(&decimal_part, &decimal_divisor);
 
@@ -400,55 +428,70 @@ fn format_as_fraction(value:&f64, format:&str)-> String {
     let mut result = String::from("");
     match format.find("0") {
         Some(_) => {
-            result = format!("{}{} {}/{}", &sign, &integer_part, &adjusted_decimal_part, &adjusted_decimal_divisor);
-        },
-        None => {
-            match format.find("#") {
-                Some(_) => {
-                    if integer_part == 0f64 {
-                        result = format!("{}{}/{}", &sign, &adjusted_decimal_part, &adjusted_decimal_divisor);
-                    } else {
-                        result = format!("{}{} {}/{}", &sign, &integer_part, &adjusted_decimal_part, &adjusted_decimal_divisor);
-                    }
-                },
-                None => {
-                    let check_format: String = format.chars().take(3).collect();
-                    if check_format == "? ?" {
-                        let mut integer_part_str = integer_part.to_string();
-                        if integer_part == 0f64 {
-                            integer_part_str = String::from("");
-                        }
-                        result = format!("{}{} {}/{}", &sign, &integer_part_str, &adjusted_decimal_part, &adjusted_decimal_divisor);
-                    } else {
-                        adjusted_decimal_part = adjusted_decimal_part + (&integer_part * &adjusted_decimal_divisor);
-                        result = format!("{}{}/{}", &sign, &adjusted_decimal_part, &adjusted_decimal_divisor);
-                    }
+            result = format!(
+                "{}{} {}/{}",
+                &sign, &integer_part, &adjusted_decimal_part, &adjusted_decimal_divisor
+            );
+        }
+        None => match format.find("#") {
+            Some(_) => {
+                if integer_part == 0f64 {
+                    result = format!(
+                        "{}{}/{}",
+                        &sign, &adjusted_decimal_part, &adjusted_decimal_divisor
+                    );
+                } else {
+                    result = format!(
+                        "{}{} {}/{}",
+                        &sign, &integer_part, &adjusted_decimal_part, &adjusted_decimal_divisor
+                    );
                 }
             }
-        
-        }
+            None => {
+                let check_format: String = format.chars().take(3).collect();
+                if check_format == "? ?" {
+                    let mut integer_part_str = integer_part.to_string();
+                    if integer_part == 0f64 {
+                        integer_part_str = String::from("");
+                    }
+                    result = format!(
+                        "{}{} {}/{}",
+                        &sign, &integer_part_str, &adjusted_decimal_part, &adjusted_decimal_divisor
+                    );
+                } else {
+                    adjusted_decimal_part =
+                        adjusted_decimal_part + (&integer_part * &adjusted_decimal_divisor);
+                    result = format!(
+                        "{}{}/{}",
+                        &sign, &adjusted_decimal_part, &adjusted_decimal_divisor
+                    );
+                }
+            }
+        },
     }
     result
 }
 
-fn format_straight_numeric_value(value:&str, format:&str, matches: &Vec<String>, use_thousands:&bool, number_regex:&str)-> String {
+fn format_straight_numeric_value(
+    value: &str,
+    _format: &str,
+    matches: &Vec<String>,
+    use_thousands: &bool,
+    _number_regex: &str,
+) -> String {
     let mut value = value.to_string();
-    let format = format.to_string();
 
-    let left = matches.get(1).unwrap();
-    let dec = matches.get(2).unwrap();
     let right = matches.get(3).unwrap();
 
     // minimun width of formatted number (including dot)
-    let min_width = left.len() + dec.len() + right.len();
     if use_thousands == &true {
         value = value.parse::<f64>().unwrap().separate_with_commas();
     }
-    let blocks:Vec<&str> = value.split('.').collect();
+    let blocks: Vec<&str> = value.split('.').collect();
     let left_value = blocks.get(0).unwrap().to_string();
     let mut right_value = match blocks.get(1) {
         Some(v) => v.to_string(),
-        None => String::from("0")
+        None => String::from("0"),
     };
     if right.len() == 0 {
         return left_value;
@@ -460,8 +503,9 @@ fn format_straight_numeric_value(value:&str, format:&str, matches: &Vec<String>,
             let pow = 10i32.pow(right.len() as u32);
             right_value = format!("{}", right_value.parse::<i32>().unwrap() * pow);
         } else {
-            let mut right_value_conv:String = right_value.chars().skip(0).take(right.len()).collect();
-            let ajst_str:String = right_value.chars().skip(right.len()).take(1).collect();
+            let mut right_value_conv: String =
+                right_value.chars().skip(0).take(right.len()).collect();
+            let ajst_str: String = right_value.chars().skip(right.len()).take(1).collect();
             let ajst_int = ajst_str.parse::<i32>().unwrap();
             if ajst_int > 4 {
                 right_value_conv = (right_value_conv.parse::<i32>().unwrap() + 1).to_string();
@@ -472,33 +516,33 @@ fn format_straight_numeric_value(value:&str, format:&str, matches: &Vec<String>,
     value = format!("{}.{}", left_value, right_value);
     value
 
-//    if use_thousands == &true {
-//        value = value.parse::<f64>().unwrap().separate_with_commas();
-//        dbg!(&value);
-//        value = Regex::new(&number_regex).unwrap().replace_all(&format, value.as_str());
-//        dbg!(&value);
-//    } else {
-//        if Regex::new(r#"[0#]E[+-]0"#).unwrap().find(&format).is_some() {
-//            // Scientific format
-//            value = value.parse::<f64>().unwrap().to_string();
-//        } else if Regex::new(r#"0([^\d\.]+)0"#).unwrap().find(&format).is_some() || format.find(".").is_some() {
-//            if value.parse::<f64>().unwrap() as usize as f64 == value.parse::<f64>().unwrap() && format.find(".").is_some() {
-//                let format_collect:Vec<&str> = format.split('.').collect();
-//                let pow = 10i32.pow(format_collect.get(1).unwrap().len() as u32);
-//                value = format!("{}", value.parse::<i32>().unwrap() * pow);
-//            }
-//            value = complex_number_format_mask(&value.parse::<f64>().unwrap(), &format, &true);
-//        } else {
-//            value = format!("{:0width$.len$}", value, width = min_width, len = right.len());
-//            value = Regex::new(&number_regex).unwrap().replace_all(&format, value.as_str());
-//        }
-//    }
-//    value
+    //    if use_thousands == &true {
+    //        value = value.parse::<f64>().unwrap().separate_with_commas();
+    //        dbg!(&value);
+    //        value = Regex::new(&number_regex).unwrap().replace_all(&format, value.as_str());
+    //        dbg!(&value);
+    //    } else {
+    //        if Regex::new(r#"[0#]E[+-]0"#).unwrap().find(&format).is_some() {
+    //            // Scientific format
+    //            value = value.parse::<f64>().unwrap().to_string();
+    //        } else if Regex::new(r#"0([^\d\.]+)0"#).unwrap().find(&format).is_some() || format.find(".").is_some() {
+    //            if value.parse::<f64>().unwrap() as usize as f64 == value.parse::<f64>().unwrap() && format.find(".").is_some() {
+    //                let format_collect:Vec<&str> = format.split('.').collect();
+    //                let pow = 10i32.pow(format_collect.get(1).unwrap().len() as u32);
+    //                value = format!("{}", value.parse::<i32>().unwrap() * pow);
+    //            }
+    //            value = complex_number_format_mask(&value.parse::<f64>().unwrap(), &format, &true);
+    //        } else {
+    //            value = format!("{:0width$.len$}", value, width = min_width, len = right.len());
+    //            value = Regex::new(&number_regex).unwrap().replace_all(&format, value.as_str());
+    //        }
+    //    }
+    //    value
 }
 
-fn merge_complex_number_format_masks(numbers:&Vec<String>, masks:&Vec<String>)-> Vec<String> {
+fn _merge_complex_number_format_masks(numbers: &Vec<String>, masks: &Vec<String>) -> Vec<String> {
     let mut decimal_count = numbers[1].len();
-    let mut post_decimal_masks:Vec<String> = Vec::new();
+    let mut post_decimal_masks: Vec<String> = Vec::new();
 
     for mask in masks.iter().rev() {
         post_decimal_masks.push(mask.to_string());
@@ -509,19 +553,19 @@ fn merge_complex_number_format_masks(numbers:&Vec<String>, masks:&Vec<String>)->
     }
 
     post_decimal_masks.reverse();
-    let mut result:Vec<String> = Vec::new();
+    let mut result: Vec<String> = Vec::new();
     result.push(masks.join("."));
     result.push(post_decimal_masks.join("."));
     result
 }
 
-fn process_complex_number_format_mask(number:&f64, mask:&str)-> String {
+fn _process_complex_number_format_mask(number: &f64, mask: &str) -> String {
     let mut result = number.to_string();
     let mut mask = mask.to_string();
     let re = Regex::new(r#"0+"#).unwrap();
-    let mut masking_blocks:Vec<(String, usize)> = Vec::new();
-    let mut masking_str:Vec<String> = Vec::new();
-    let mut masking_beg:Vec<usize> = Vec::new();
+    let mut masking_blocks: Vec<(String, usize)> = Vec::new();
+    let mut masking_str: Vec<String> = Vec::new();
+    let mut masking_beg: Vec<usize> = Vec::new();
     for ite in re.captures(&mask).unwrap().iter() {
         masking_str.push(ite.unwrap().to_string());
     }
@@ -530,12 +574,15 @@ fn process_complex_number_format_mask(number:&f64, mask:&str)-> String {
         masking_beg.push(beg);
     }
     for i in 0..masking_str.len() {
-        masking_blocks.push((masking_str.get(i).unwrap().clone(), masking_beg.get(i).unwrap().clone()));
+        masking_blocks.push((
+            masking_str.get(i).unwrap().clone(),
+            masking_beg.get(i).unwrap().clone(),
+        ));
     }
 
     if masking_blocks.len() > 1 {
         let mut number = number.clone();
-        let mut offset:usize = 0;
+        let mut offset: usize = 0;
         for (block, pos) in masking_blocks.iter().rev() {
             let divisor = format!("{}{}", 1, block).parse::<f64>().unwrap();
             let size = block.len();
@@ -556,37 +603,47 @@ fn process_complex_number_format_mask(number:&f64, mask:&str)-> String {
     result
 }
 
-fn complex_number_format_mask(number:&f64, mask:&str, split_on_point:&bool)->String {
+fn _complex_number_format_mask(number: &f64, mask: &str, split_on_point: &bool) -> String {
     let sign = number < &0.0;
     let number = number.abs();
 
-    if split_on_point == &true && mask.find(".").is_some() && number.to_string().find(".").is_some() {
+    if split_on_point == &true && mask.find(".").is_some() && number.to_string().find(".").is_some()
+    {
         let number_str = number.to_string();
-        let numbers_as:Vec<&str> = number_str.split('.').collect();
-        let mut numbers:Vec<String> = Vec::new();
+        let numbers_as: Vec<&str> = number_str.split('.').collect();
+        let mut numbers: Vec<String> = Vec::new();
         for n in numbers_as {
             numbers.push(n.to_string());
         }
-        let masks_as:Vec<&str> = mask.split('.').collect();
-        let mut masks:Vec<String> = Vec::new();
+        let masks_as: Vec<&str> = mask.split('.').collect();
+        let mut masks: Vec<String> = Vec::new();
         for mask in masks_as {
             masks.push(mask.to_string());
         }
         if masks.len() > 2 {
-            masks = merge_complex_number_format_masks(&numbers, &masks);
+            masks = _merge_complex_number_format_masks(&numbers, &masks);
         }
-        let result1 = complex_number_format_mask(&numbers[0].parse::<f64>().unwrap(), &masks[0], &false);
-        let result2 = complex_number_format_mask(
-            &numbers[1].chars().rev().collect::<String>().parse::<f64>().unwrap(),
+        let result1 =
+            _complex_number_format_mask(&numbers[0].parse::<f64>().unwrap(), &masks[0], &false);
+        let result2 = _complex_number_format_mask(
+            &numbers[1]
+                .chars()
+                .rev()
+                .collect::<String>()
+                .parse::<f64>()
+                .unwrap(),
             &masks[1].chars().rev().collect::<String>(),
-            &false
-        ).chars().rev().collect::<String>();
-        
-        return format!("{}{}.{}", if sign { "-" } else { "" } , result1, result2);
+            &false,
+        )
+        .chars()
+        .rev()
+        .collect::<String>();
+
+        return format!("{}{}.{}", if sign { "-" } else { "" }, result1, result2);
     }
 
-    let result = process_complex_number_format_mask(&number, mask);
-    format!("{}{}", if sign { "-" } else { "" } , result)
+    let result = _process_complex_number_format_mask(&number, mask);
+    format!("{}{}", if sign { "-" } else { "" }, result)
 }
 
 fn gcd(a: &f64, b: &f64) -> f64 {
@@ -600,50 +657,182 @@ fn gcd(a: &f64, b: &f64) -> f64 {
 #[test]
 fn test_to_formatted_string_date() {
     let value = String::from("45435"); // 2024/5/23
-    assert_eq!(r#"2024-05-23"#,   to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD2));
-    assert_eq!(r#"2024-05-23"#,   to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD));
-    assert_eq!(r#"23-05-2024"#,   to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYY));
-    assert_eq!(r#"23/05/2024"#,   to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYYSLASH));
-    assert_eq!(r#"23/5/24"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYSLASH));
-    assert_eq!(r#"23-5-24"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYMINUS));
-    assert_eq!(r#"23-5"#,         to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMMINUS));
-    assert_eq!(r#"5-24"#,         to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_MYMINUS));
-    assert_eq!(r#"05-23-24"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX14));
-    assert_eq!(r#"23-May-24"#,    to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX15));
-    assert_eq!(r#"23-May"#,       to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX16));
-    assert_eq!(r#"May-24"#,       to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX17));
-    assert_eq!(r#"5/23/24 0:00"#, to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX22));
-    assert_eq!(r#"23/5/24 0:00"#, to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DATETIME));
-    assert_eq!(r#"12:00 am"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME1));
-    assert_eq!(r#"12:00:00 am"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME2));
-    assert_eq!(r#"0:00"#,         to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME3));
-    assert_eq!(r#"0:00:00"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME4));
-    assert_eq!(r#"00:00"#,        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME5));
-    assert_eq!(r#"0:00:00"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME6));
-    assert_eq!(r#"0:00:00"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME8));
-    assert_eq!(r#"2024/05/23"#,   to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDDSLASH));
+    assert_eq!(
+        r#"2024-05-23"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD2)
+    );
+    assert_eq!(
+        r#"2024-05-23"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD)
+    );
+    assert_eq!(
+        r#"23-05-2024"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYY)
+    );
+    assert_eq!(
+        r#"23/05/2024"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYYSLASH)
+    );
+    assert_eq!(
+        r#"23/5/24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYSLASH)
+    );
+    assert_eq!(
+        r#"23-5-24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYMINUS)
+    );
+    assert_eq!(
+        r#"23-5"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMMINUS)
+    );
+    assert_eq!(
+        r#"5-24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_MYMINUS)
+    );
+    assert_eq!(
+        r#"05-23-24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX14)
+    );
+    assert_eq!(
+        r#"23-May-24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX15)
+    );
+    assert_eq!(
+        r#"23-May"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX16)
+    );
+    assert_eq!(
+        r#"May-24"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX17)
+    );
+    assert_eq!(
+        r#"5/23/24 0:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX22)
+    );
+    assert_eq!(
+        r#"23/5/24 0:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DATETIME)
+    );
+    assert_eq!(
+        r#"12:00 am"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME1)
+    );
+    assert_eq!(
+        r#"12:00:00 am"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME2)
+    );
+    assert_eq!(
+        r#"0:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME3)
+    );
+    assert_eq!(
+        r#"0:00:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME4)
+    );
+    assert_eq!(
+        r#"00:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME5)
+    );
+    assert_eq!(
+        r#"0:00:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME6)
+    );
+    assert_eq!(
+        r#"0:00:00"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME8)
+    );
+    assert_eq!(
+        r#"2024/05/23"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDDSLASH)
+    );
 
     let value = String::from("44349.211134259262"); // 2021/06/02 05:04:02
-    assert_eq!(r#"2021-06-02"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD2));
-    assert_eq!(r#"2021-06-02"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD));
-    assert_eq!(r#"02-06-2021"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYY));
-    assert_eq!(r#"02/06/2021"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYYSLASH));
-    assert_eq!(r#"2/6/21"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYSLASH));
-    assert_eq!(r#"2-6-21"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYMINUS));
-    assert_eq!(r#"2-6"#,         to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMMINUS));
-    assert_eq!(r#"6-21"#,        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_MYMINUS));
-    assert_eq!(r#"06-02-21"#,    to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX14));
-    assert_eq!(r#"2-Jun-21"#,    to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX15));
-    assert_eq!(r#"2-Jun"#,       to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX16));
-    assert_eq!(r#"Jun-21"#,      to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX17));
-    assert_eq!(r#"6/2/21 5:04"#, to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX22));
-    assert_eq!(r#"2/6/21 5:04"#, to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DATETIME));
-    assert_eq!(r#"5:04 am"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME1));
-    assert_eq!(r#"5:04:02 am"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME2));
-    assert_eq!(r#"5:04"#,        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME3));
-    assert_eq!(r#"5:04:02"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME4));
-    assert_eq!(r#"04:02"#,       to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME5));
-    assert_eq!(r#"5:04:02"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME6));
-    assert_eq!(r#"5:04:02"#,     to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME8));
-    assert_eq!(r#"2021/06/02"#,  to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDDSLASH));
+    assert_eq!(
+        r#"2021-06-02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD2)
+    );
+    assert_eq!(
+        r#"2021-06-02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDD)
+    );
+    assert_eq!(
+        r#"02-06-2021"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYY)
+    );
+    assert_eq!(
+        r#"02/06/2021"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DDMMYYYYSLASH)
+    );
+    assert_eq!(
+        r#"2/6/21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYSLASH)
+    );
+    assert_eq!(
+        r#"2-6-21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMYMINUS)
+    );
+    assert_eq!(
+        r#"2-6"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DMMINUS)
+    );
+    assert_eq!(
+        r#"6-21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_MYMINUS)
+    );
+    assert_eq!(
+        r#"06-02-21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX14)
+    );
+    assert_eq!(
+        r#"2-Jun-21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX15)
+    );
+    assert_eq!(
+        r#"2-Jun"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX16)
+    );
+    assert_eq!(
+        r#"Jun-21"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX17)
+    );
+    assert_eq!(
+        r#"6/2/21 5:04"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_XLSX22)
+    );
+    assert_eq!(
+        r#"2/6/21 5:04"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_DATETIME)
+    );
+    assert_eq!(
+        r#"5:04 am"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME1)
+    );
+    assert_eq!(
+        r#"5:04:02 am"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME2)
+    );
+    assert_eq!(
+        r#"5:04"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME3)
+    );
+    assert_eq!(
+        r#"5:04:02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME4)
+    );
+    assert_eq!(
+        r#"04:02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME5)
+    );
+    assert_eq!(
+        r#"5:04:02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME6)
+    );
+    assert_eq!(
+        r#"5:04:02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_TIME8)
+    );
+    assert_eq!(
+        r#"2021/06/02"#,
+        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_DATE_YYYYMMDDSLASH)
+    );
 }
