@@ -32,17 +32,21 @@ pub fn read<R: io::Read + io::Seek>(
                             color.set_argb_by_theme(&theme);
                         }
                         for fill in obj.get_fills_mut().get_fill_mut() {
-                            match fill.get_pattern_fill_mut() {
-                                Some(v) => {
-                                    match v.get_foreground_color_mut() {
-                                        Some(c) => {
-                                            c.set_argb_by_theme(&theme);
+                            match fill.get_pattern_fill() {
+                                Some(_) => {
+                                    match fill.get_pattern_fill_mut().get_foreground_color() {
+                                        Some(_) => {
+                                            fill.get_pattern_fill_mut()
+                                                .get_foreground_color_mut()
+                                                .set_argb_by_theme(&theme);
                                         }
                                         None => {}
                                     }
-                                    match v.get_background_color_mut() {
-                                        Some(c) => {
-                                            c.set_argb_by_theme(&theme);
+                                    match fill.get_pattern_fill_mut().get_background_color() {
+                                        Some(_) => {
+                                            fill.get_pattern_fill_mut()
+                                                .get_background_color_mut()
+                                                .set_argb_by_theme(&theme);
                                         }
                                         None => {}
                                     }
