@@ -75,6 +75,19 @@ impl Cells {
         false
     }
 
+    /// Has Hyperlink
+    pub(crate) fn has_hyperlink(&self) -> bool {
+        for cell in &self.index {
+            match cell.get_hyperlink() {
+                Some(_) => {
+                    return true;
+                }
+                None => {}
+            }
+        }
+        false
+    }
+
     pub(crate) fn get(&self, col_num: &u32, row_num: &u32) -> Option<&Cell> {
         for cell in &self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
@@ -124,8 +137,12 @@ impl Cells {
     pub(crate) fn set(&mut self, cell: Cell) -> &mut Self {
         let col_num = cell.get_coordinate().get_col_num();
         let row_num = cell.get_coordinate().get_row_num();
-        self.index
-            .retain(|x| !x.get_coordinate().is_mine(col_num, row_num));
+        let target_cell = self.get_mut(col_num, row_num);
+        target_cell.set_obj(cell);
+        self
+    }
+
+    pub(crate) fn set_fast(&mut self, cell: Cell) -> &mut Self {
         self.add(cell);
         self
     }
@@ -143,4 +160,11 @@ impl Cells {
         }
         result
     }
+
+    pub(crate) fn get_formatted_value_by_column_and_row(&self, col: &u32, row: &u32) -> String {
+        match self.get(col, row) {
+            Some(v) => v.get_formatted_value(),
+            None => "".into(),
+        }
+    }
 }
