@@ -1,10 +1,10 @@
-use super::RichText;
-use super::Coordinate;
 use super::vml::spreadsheet::Anchor;
-use structs::vml::Shape;
+use super::Coordinate;
+use super::RichText;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use reader::driver::*;
+use structs::vml::Shape;
 
 #[derive(Clone, Default, Debug)]
 pub struct Comment {
@@ -14,32 +14,32 @@ pub struct Comment {
     shape: Shape,
 }
 impl Comment {
-    pub fn get_coordinate(&self)-> &Coordinate {
+    pub fn get_coordinate(&self) -> &Coordinate {
         &self.coordinate
     }
 
-    pub fn get_coordinate_mut(&mut self)-> &mut Coordinate {
+    pub fn get_coordinate_mut(&mut self) -> &mut Coordinate {
         &mut self.coordinate
     }
 
-    pub fn get_author(&self)->&str {
+    pub fn get_author(&self) -> &str {
         &self.author
     }
 
-    pub fn set_author<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    pub fn set_author<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.author = value.into();
         self
     }
 
-    pub fn get_text(&self)->&RichText {
+    pub fn get_text(&self) -> &RichText {
         &self.text
     }
 
-    pub fn get_text_mut(&mut self)->&mut RichText {
+    pub fn get_text_mut(&mut self) -> &mut RichText {
         &mut self.text
     }
 
-    pub fn set_text(&mut self, value:RichText) -> &mut Self {
+    pub fn set_text(&mut self, value: RichText) -> &mut Self {
         self.text = value;
         self
     }
@@ -52,7 +52,7 @@ impl Comment {
         self.shape.get_client_data_mut().get_anchor_mut()
     }
 
-    pub fn set_anchor(&mut self, value:Anchor) -> &mut Self {
+    pub fn set_anchor(&mut self, value: Anchor) -> &mut Self {
         self.shape.get_client_data_mut().set_anchor(value);
         self
     }
@@ -70,49 +70,89 @@ impl Comment {
         self
     }
 
-    pub(crate) fn adjustment_insert_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
+    pub(crate) fn adjustment_insert_coordinate(
+        &mut self,
+        root_col_num: &u32,
+        offset_col_num: &u32,
+        root_row_num: &u32,
+        offset_row_num: &u32,
+    ) {
         let org_col_num = self.coordinate.get_col_num().clone();
         let org_row_num = self.coordinate.get_row_num().clone();
-        self.coordinate.adjustment_insert_coordinate(root_col_num, offset_col_num, root_row_num, offset_row_num);
+        self.coordinate.adjustment_insert_coordinate(
+            root_col_num,
+            offset_col_num,
+            root_row_num,
+            offset_row_num,
+        );
         if &org_col_num != self.coordinate.get_col_num() {
-            self.get_anchor_mut().adjustment_insert_colmun(offset_col_num);
-            match self.get_shape_mut().get_client_data_mut().get_comment_column_target_mut() {
+            self.get_anchor_mut()
+                .adjustment_insert_colmun(offset_col_num);
+            match self
+                .get_shape_mut()
+                .get_client_data_mut()
+                .get_comment_column_target_mut()
+            {
                 Some(v) => {
                     v.adjustment_insert_colmun(offset_col_num);
-                },
+                }
                 None => {}
             }
         }
         if &org_row_num != self.coordinate.get_row_num() {
             self.get_anchor_mut().adjustment_insert_row(offset_row_num);
-            match self.get_shape_mut().get_client_data_mut().get_comment_row_target_mut() {
+            match self
+                .get_shape_mut()
+                .get_client_data_mut()
+                .get_comment_row_target_mut()
+            {
                 Some(v) => {
                     v.adjustment_insert_row(offset_row_num);
-                },
+                }
                 None => {}
             }
         }
     }
 
-    pub(crate) fn adjustment_remove_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
+    pub(crate) fn adjustment_remove_coordinate(
+        &mut self,
+        root_col_num: &u32,
+        offset_col_num: &u32,
+        root_row_num: &u32,
+        offset_row_num: &u32,
+    ) {
         let org_col_num = self.coordinate.get_col_num().clone();
         let org_row_num = self.coordinate.get_row_num().clone();
-        self.coordinate.adjustment_remove_coordinate(root_col_num, offset_col_num, root_row_num, offset_row_num);
+        self.coordinate.adjustment_remove_coordinate(
+            root_col_num,
+            offset_col_num,
+            root_row_num,
+            offset_row_num,
+        );
         if &org_col_num != self.coordinate.get_col_num() {
-            self.get_anchor_mut().adjustment_remove_colmun(offset_col_num);
-            match self.get_shape_mut().get_client_data_mut().get_comment_column_target_mut() {
+            self.get_anchor_mut()
+                .adjustment_remove_colmun(offset_col_num);
+            match self
+                .get_shape_mut()
+                .get_client_data_mut()
+                .get_comment_column_target_mut()
+            {
                 Some(v) => {
                     v.adjustment_remove_colmun(offset_col_num);
-                },
+                }
                 None => {}
             }
         }
         if &org_row_num != self.coordinate.get_row_num() {
             self.get_anchor_mut().adjustment_remove_row(offset_row_num);
-            match self.get_shape_mut().get_client_data_mut().get_comment_row_target_mut() {
+            match self
+                .get_shape_mut()
+                .get_client_data_mut()
+                .get_comment_row_target_mut()
+            {
                 Some(v) => {
                     v.adjustment_remove_row(offset_row_num);
-                },
+                }
                 None => {}
             }
         }
@@ -122,12 +162,15 @@ impl Comment {
         &mut self,
         reader: &mut Reader<R>,
         e: &BytesStart,
-        authors: &Vec<String>
+        authors: &Vec<String>,
     ) {
         let coordinate = get_attribute(e, b"ref").unwrap();
         self.get_coordinate_mut().set_coordinate(coordinate);
 
-        let author_id = get_attribute(e, b"authorId").unwrap().parse::<usize>().unwrap();
+        let author_id = get_attribute(e, b"authorId")
+            .unwrap()
+            .parse::<usize>()
+            .unwrap();
         let author = authors.get(author_id).unwrap();
         self.set_author(author);
 
@@ -137,13 +180,11 @@ impl Comment {
                 Ok(Event::Start(ref e)) => match e.name() {
                     b"text" => {
                         self.get_text_mut().set_attributes_text(reader, e);
-                    },
+                    }
                     _ => (),
                 },
                 Ok(Event::End(ref e)) => match e.name() {
-                    b"comment" => {
-                        return
-                    },
+                    b"comment" => return,
                     _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "comment"),
