@@ -1,19 +1,17 @@
 // c:majorGridlines
-use writer::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
-pub struct MajorGridlines {
-}
+pub struct MajorGridlines {}
 impl MajorGridlines {
-
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        _e:&BytesStart
+        _reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
     }
 
