@@ -63,12 +63,12 @@ impl RichText {
                     b"a:p" => {
                         let mut paragraph = Paragraph::default();
                         paragraph.set_attributes(reader, e);
-                        &mut self.add_paragraph(paragraph);
+                        self.add_paragraph(paragraph);
                     }
                     b"a:bodyPr" => {
                         let mut body_properties = BodyProperties::default();
                         body_properties.set_attributes(reader, e, false);
-                        &mut self.set_body_properties(body_properties);
+                        self.set_body_properties(body_properties);
                     }
                     _ => (),
                 },
@@ -76,7 +76,7 @@ impl RichText {
                     b"a:bodyPr" => {
                         let mut body_properties = BodyProperties::default();
                         body_properties.set_attributes(reader, e, true);
-                        &mut self.set_body_properties(body_properties);
+                        self.set_body_properties(body_properties);
                     }
                     _ => (),
                 },
@@ -97,7 +97,7 @@ impl RichText {
         write_start_tag(writer, "c:rich", vec![], false);
 
         // a:bodyPr
-        &self.body_properties.write_to(writer);
+        self.body_properties.write_to(writer);
 
         // a:lstStyle
         write_start_tag(writer, "a:lstStyle", vec![], true);
