@@ -1,9 +1,9 @@
 // a:fillRect
-use writer::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct FillRectangle {
@@ -17,7 +17,7 @@ impl FillRectangle {
         &self.bottom
     }
 
-    pub fn set_bottom(&mut self, value:usize) {
+    pub fn set_bottom(&mut self, value: usize) {
         self.bottom = value;
     }
 
@@ -25,7 +25,7 @@ impl FillRectangle {
         &self.left
     }
 
-    pub fn set_left(&mut self, value:usize) {
+    pub fn set_left(&mut self, value: usize) {
         self.left = value;
     }
 
@@ -33,7 +33,7 @@ impl FillRectangle {
         &self.right
     }
 
-    pub fn set_right(&mut self, value:usize) {
+    pub fn set_right(&mut self, value: usize) {
         self.right = value;
     }
 
@@ -41,16 +41,15 @@ impl FillRectangle {
         &self.top
     }
 
-    pub fn set_top(&mut self, value:usize) {
+    pub fn set_top(&mut self, value: usize) {
         self.top = value;
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        _e:&BytesStart
+        _reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
-
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
