@@ -61,7 +61,7 @@ impl ForegroundColor {
         write_start_tag(writer, "a:fgClr", vec![], false);
 
         // a:schemeClr
-        &self.scheme_color.write_to(writer);
+        let _ = &self.scheme_color.write_to(writer);
 
         write_end_tag(writer, "a:fgClr");
     }
