@@ -31,38 +31,40 @@ pub enum LightRigValues {
     TwoPoints,
 }
 impl Default for LightRigValues {
-    fn default() -> Self { Self::LegacyFlat1 }
+    fn default() -> Self {
+        Self::LegacyFlat1
+    }
 }
 impl EnumTrait for LightRigValues {
-    fn get_value_string(&self)->&str {
+    fn get_value_string(&self) -> &str {
         match &self {
-            Self::Balanced => {"balanced"},
-            Self::BrightRoom => {"brightRoom"},
-            Self::Chilly => {"chilly"},
-            Self::Contrasting => {"contrasting"},
-            Self::Flat => {"flat"},
-            Self::Flood => {"flood"},
-            Self::Freezing => {"freezing"},
-            Self::Glow => {"glow"},
-            Self::Harsh => {"harsh"},
-            Self::LegacyFlat1 => {"legacyFlat1"},
-            Self::LegacyFlat2 => {"legacyFlat2"},
-            Self::LegacyFlat3 => {"legacyFlat3"},
-            Self::LegacyFlat4 => {"legacyFlat4"},
-            Self::LegacyHarsh1 => {"legacyHarsh1"},
-            Self::LegacyHarsh2 => {"legacyHarsh2"},
-            Self::LegacyHarsh3 => {"legacyHarsh3"},
-            Self::LegacyHarsh4 => {"legacyHarsh4"},
-            Self::LegacyNormal1 => {"legacyNormal1"},
-            Self::LegacyNormal2 => {"legacyNormal2"},
-            Self::LegacyNormal3 => {"legacyNormal3"},
-            Self::LegacyNormal4 => {"legacyNormal4"},
-            Self::Morning => {"morning"},
-            Self::Soft => {"soft"},
-            Self::Sunrise => {"sunrise"},
-            Self::Sunset => {"sunset"},
-            Self::ThreePoints => {"threePt"},
-            Self::TwoPoints => {"twoPt"},
+            Self::Balanced => "balanced",
+            Self::BrightRoom => "brightRoom",
+            Self::Chilly => "chilly",
+            Self::Contrasting => "contrasting",
+            Self::Flat => "flat",
+            Self::Flood => "flood",
+            Self::Freezing => "freezing",
+            Self::Glow => "glow",
+            Self::Harsh => "harsh",
+            Self::LegacyFlat1 => "legacyFlat1",
+            Self::LegacyFlat2 => "legacyFlat2",
+            Self::LegacyFlat3 => "legacyFlat3",
+            Self::LegacyFlat4 => "legacyFlat4",
+            Self::LegacyHarsh1 => "legacyHarsh1",
+            Self::LegacyHarsh2 => "legacyHarsh2",
+            Self::LegacyHarsh3 => "legacyHarsh3",
+            Self::LegacyHarsh4 => "legacyHarsh4",
+            Self::LegacyNormal1 => "legacyNormal1",
+            Self::LegacyNormal2 => "legacyNormal2",
+            Self::LegacyNormal3 => "legacyNormal3",
+            Self::LegacyNormal4 => "legacyNormal4",
+            Self::Morning => "morning",
+            Self::Soft => "soft",
+            Self::Sunrise => "sunrise",
+            Self::Sunset => "sunset",
+            Self::ThreePoints => "threePt",
+            Self::TwoPoints => "twoPt",
         }
     }
 }
@@ -97,7 +99,7 @@ impl FromStr for LightRigValues {
             "sunset" => Ok(Self::Sunset),
             "threePt" => Ok(Self::ThreePoints),
             "twoPt" => Ok(Self::TwoPoints),
-            _      => Err(()),
+            _ => Err(()),
         }
     }
 }
