@@ -1,12 +1,12 @@
 // a:lin
-use super::super::super::Int32Value;
 use super::super::super::BooleanValue;
-use writer::driver::*;
-use reader::driver::*;
+use super::super::super::Int32Value;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct LinearGradientFill {
@@ -14,36 +14,40 @@ pub struct LinearGradientFill {
     scaled: BooleanValue,
 }
 impl LinearGradientFill {
-    pub fn get_angle(&self)-> &i32 {
+    pub fn get_angle(&self) -> &i32 {
         &self.angle.get_value()
     }
-    
-    pub fn set_angle(&mut self, value:i32)-> &mut LinearGradientFill {
+
+    pub fn set_angle(&mut self, value: i32) -> &mut LinearGradientFill {
         self.angle.set_value(value);
         self
     }
 
-    pub fn get_scaled(&self)-> &bool {
+    pub fn get_scaled(&self) -> &bool {
         &self.scaled.get_value()
     }
-    
-    pub fn set_scaled(&mut self, value:bool)-> &mut LinearGradientFill {
+
+    pub fn set_scaled(&mut self, value: bool) -> &mut LinearGradientFill {
         self.scaled.set_value(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         match get_attribute(e, b"ang") {
-            Some(v) => {self.angle.set_value_string(v);},
-            None => {},
+            Some(v) => {
+                self.angle.set_value_string(v);
+            }
+            None => {}
         }
         match get_attribute(e, b"scaled") {
-            Some(v) => {self.scaled.set_value_string(v);},
-            None => {},
+            Some(v) => {
+                self.scaled.set_value_string(v);
+            }
+            None => {}
         }
     }
 
