@@ -1,7 +1,7 @@
 // a:gd
-use writer::driver::*;
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct ShapeGuide {
@@ -13,7 +13,7 @@ impl ShapeGuide {
         &self.name
     }
 
-    pub fn set_name<S: Into<String>>(&mut self, value:S) {
+    pub fn set_name<S: Into<String>>(&mut self, value: S) {
         self.name = value.into();
     }
 
@@ -21,14 +21,16 @@ impl ShapeGuide {
         &self.fmla
     }
 
-    pub fn set_fmla<S: Into<String>>(&mut self, value:S) {
+    pub fn set_fmla<S: Into<String>>(&mut self, value: S) {
         self.fmla = value.into();
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
-        write_start_tag(writer, "a:gd", vec![
-            ("name", &self.name),
-            ("fmla", &self.fmla),
-        ], true);
+        write_start_tag(
+            writer,
+            "a:gd",
+            vec![("name", &self.name), ("fmla", &self.fmla)],
+            true,
+        );
     }
 }
