@@ -14,6 +14,48 @@ pub struct Style {
     numbering_format: Option<NumberingFormat>,
     format_id: UInt32Value,
 }
+/// # Examples
+/// ## add border
+/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/style/style_border.png)
+/// ```rust
+/// use umya_spreadsheet::*;
+/// let mut book = new_file();
+/// let mut style = book.get_sheet_by_name_mut("Sheet1").unwrap().get_style_mut("D2");
+///
+/// // add bottom border
+/// style.get_borders_mut().get_bottom_mut().set_border_style(Border::BORDER_MEDIUM);
+/// // add top border
+/// style.get_borders_mut().get_top_mut().set_border_style(Border::BORDER_MEDIUM);
+/// // add left border
+/// style.get_borders_mut().get_left_mut().set_border_style(Border::BORDER_MEDIUM);
+/// // add right border
+/// style.get_borders_mut().get_right_mut().set_border_style(Border::BORDER_MEDIUM);
+/// ```
+///
+/// ## change cell color
+/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/style/style_fill_color.png)
+/// ```rust
+/// use umya_spreadsheet::*;
+///
+/// let mut book = new_file();
+/// let mut style = book.get_sheet_by_name_mut("Sheet1").unwrap().get_style_mut("A1");
+///
+/// // fill color on red.
+/// style.get_fill_mut().get_pattern_fill_mut()
+/// .get_foreground_color_mut().set_argb(Color::COLOR_RED);
+/// ```
+///
+/// ## change font color
+/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/style/style_font_color.png)
+/// ```rust
+/// use umya_spreadsheet::*;
+///
+/// let mut book = new_file();
+/// let mut style = book.get_sheet_by_name_mut("Sheet1").unwrap().get_style_mut("A1");
+///
+/// // font color on red.
+/// style.get_font_mut().get_color_mut().set_argb(Color::COLOR_RED);
+/// ```
 impl Style {
     pub fn get_font(&self) -> &Option<Font> {
         &self.font
@@ -33,6 +75,11 @@ impl Style {
         self
     }
 
+    pub fn remove_font(&mut self) -> &mut Self {
+        self.font = None;
+        self
+    }
+
     pub(crate) fn set_font_crate(&mut self, value: Option<Font>) -> &mut Self {
         self.font = value;
         self
@@ -56,6 +103,11 @@ impl Style {
         self
     }
 
+    pub fn remove_fill(&mut self) -> &mut Self {
+        self.fill = None;
+        self
+    }
+
     pub(crate) fn set_fill_crate(&mut self, value: Option<Fill>) -> &mut Self {
         self.fill = value;
         self
@@ -79,6 +131,11 @@ impl Style {
         self
     }
 
+    pub fn remove_borders(&mut self) -> &mut Self {
+        self.borders = None;
+        self
+    }
+
     pub(crate) fn set_borders_crate(&mut self, value: Option<Borders>) -> &mut Self {
         self.borders = value;
         self
@@ -102,6 +159,11 @@ impl Style {
         self
     }
 
+    pub fn remove_alignment(&mut self) -> &mut Self {
+        self.alignment = None;
+        self
+    }
+
     pub(crate) fn set_alignment_crate(&mut self, value: Option<Alignment>) -> &mut Self {
         self.alignment = value;
         self
@@ -125,6 +187,11 @@ impl Style {
         self
     }
 
+    pub fn remove_numbering_format(&mut self) -> &mut Self {
+        self.numbering_format = None;
+        self
+    }
+
     pub fn get_number_format(&self) -> &Option<NumberingFormat> {
         &self.get_numbering_format()
     }
@@ -137,6 +204,10 @@ impl Style {
         self.set_numbering_format(value)
     }
 
+    pub fn remove_number_format(&mut self) -> &mut Self {
+        self.remove_numbering_format()
+    }
+
     pub fn get_format_id(&self) -> &u32 {
         self.format_id.get_value()
     }
@@ -154,6 +225,14 @@ impl Style {
         def
     }
 
+    pub(crate) fn get_defalut_value_2() -> Self {
+        let mut def = Self::default();
+        def.set_font(Font::get_defalut_value());
+        def.set_borders(Borders::get_defalut_value());
+        def.set_fill(Fill::get_defalut_value_2());
+        def
+    }
+
     pub(crate) fn get_hash_code(&self) -> String {
         format!(
             "{:x}",
