@@ -8,7 +8,7 @@ use reader::driver::*;
 use std::io::Cursor;
 use writer::driver::*;
 
-#[derive(Clone, Default, Debug)]
+#[derive(Clone, Default, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub struct VerticalTextAlignment {
     pub(crate) val: EnumValue<VerticalAlignmentRunValues>,
 }
