@@ -11,8 +11,8 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     file_name: &str,
 ) -> Result<(), XlsxError> {
     match spreadsheet.get_has_macros() {
-        &true => {}
-        &false => return Ok(()),
+        true => {}
+        false => return Ok(()),
     }
     let writer = spreadsheet.get_macros_code().as_ref().unwrap();
     let _ = make_file_from_bin(&file_name, arv, writer, Some(sub_dir)).unwrap();
