@@ -3,13 +3,14 @@ use quick_xml::Writer;
 use std::io;
 
 use super::driver::*;
+use super::XlsxError;
 use structs::Spreadsheet;
 use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     spreadsheet: &Spreadsheet,
     writer_mng: &mut WriterManager<W>,
-) {
+) -> Result<(), XlsxError> {
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
     let _ = writer.write_event(Event::Decl(BytesDecl::new(
@@ -166,6 +167,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     );
 
     write_end_tag(&mut writer, "workbook");
-    let _ =
-        make_file_from_writer("xl/workbook.xml", writer_mng.get_arv_mut(), writer, None).unwrap();
+
+    make_file_from_writer("xl/workbook.xml", writer_mng.get_arv_mut(), writer, None)?;
+    Ok(())
 }
